@@ -7,14 +7,16 @@ class Acme::Client::Resources::Directory
     new_order: 'newOrder',
     new_authz: 'newAuthz',
     revoke_certificate: 'revokeCert',
-    key_change: 'keyChange'
+    key_change: 'keyChange',
+    renewal_info: 'renewalInfo'
   }
 
   DIRECTORY_META = {
     terms_of_service: 'termsOfService',
     website: 'website',
     caa_identities: 'caaIdentities',
-    external_account_required: 'externalAccountRequired'
+    external_account_required: 'externalAccountRequired',
+    profiles: 'profiles'
   }
 
   def initialize(client, **arguments)
@@ -45,6 +47,10 @@ class Acme::Client::Resources::Directory
     meta[DIRECTORY_META[:external_account_required]]
   end
 
+  def profiles
+    meta[DIRECTORY_META[:profiles]]
+  end
+
   def meta
     @directory[:meta]
   end
